TicketKeyCallbackResult

Enum TicketKeyCallbackResult 

pub enum TicketKeyCallbackResult {
    Error,
    Noop,
    Success,
    DecryptSuccessRenew,
}
Ticket key callback status.

Variants



Error

Abort the handshake.



Noop

Continue with a full handshake.

When in decryption mode, this indicates that the peer supplied session ticket was not recognized. When in encryption mode, this instructs boring to not send a session ticket.

Note

This is a decryption specific status code when using the submoduled BoringSSL.



Success

Resumption callback was successful.

When in decryption mode, attempt an abbreviated handshake via session resumption. When in encryption mode, provide a new ticket to the client.



DecryptSuccessRenew

Resumption callback was successful. Attempt an abbreviated handshake, and additionally provide new session tickets to the peer.

Session resumption short-circuits some security checks of a full-handshake, in exchange for potential performance gains. For this reason, a session ticket should only be valid for a limited time. Providing the peer with renewed session tickets allows them to continue session resumption with the new tickets.

Note

This is a decryption specific status code.