SslCredential

Struct SslCredential 

pub struct SslCredential(/* private fields */);
A credential.

Implementations

Source

impl SslCredential

pub fn new_ex_index<T>() -> Result<Index<Self, T>, ErrorStack>
where T: 'static + Sync + Send,

Returns a new extra data index.

Each invocation of this function is guaranteed to return a distinct index. These can be used to store data in the context that can be retrieved later by callbacks, for example.

This corresponds to SSL_C_get_ex_new_index.

Methods from Deref<Target = SslCredentialRef>

pub fn ex_data<T>(&self, index: Index<SslCredential, T>) -> Option<&T>

Returns a reference to the extra data at the specified index.

This corresponds to SSL_CREDENTIAL_get_ex_data.